import type { List, ListIterator } from "lodash";
/**
 * Counts the values of an array into a map,
 * with the key being based on a key mapper and the value being the occurrences
 * of the key mapper result in the initial array.
 *
 * @since 12.0.0
 * @category Array
 * @param array Array to count.
 * @param keyMapper Function to use for key generation.
 * @returns Count map.
 * @example
 * countMapBy([1, 2, 4, 2, 4, 4], val => val)
 * // => Map{1: 1, 2: 2, 4: 3}
 */
declare const countMapBy: <TValue, UKey>(array: List<TValue>, keyMapper: ListIterator<TValue, UKey>) => Map<UKey, number>;
export { countMapBy };
//# sourceMappingURL=countMapBy.d.ts.map