"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pullFirst = void 0;
const lodash_1 = require("lodash");
/**
 * Removes the first occurrence of an element from an array.
 * If the element does not exist in the array nothing is done.
 *
 * Note that the input array is being mutated.
 *
 * @since 2.8.0
 * @category Array
 * @param array Array to modify.
 * @param value The value to remove.
 * @returns The mutated array.
 * @example
 * const a = ["foo", "bar", "fizz", "bar"];
 * removeItem(a, "bar")
 * // => ["foo", "fizz", "bar"]
 *
 * const b = ["foo", "bar", "fizz", "bar"];
 * removeItem(b, "bazz")
 * // => ["foo", "bar", "fizz", "bar"]
 */
const pullFirst = (array, value) => {
    const targetIndex = lodash_1.indexOf(array, value);
    lodash_1.remove(array, (_val, index) => index === targetIndex);
    return array;
};
exports.pullFirst = pullFirst;
//# sourceMappingURL=pullFirst.js.map