"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.name = void 0;
const lodash_1 = require("lodash");
/**
 * Gets name of a value.
 *
 * If the value is a function, its name is returned.
 * If the value is a symbol, its key is returned.
 * If the value is a string, it is returned as is.
 * Otherwise null is returned.
 *
 * @since 10.2.0
 * @category Lang
 * @param value Value to check.
 * @returns The name of the value.
 * @example
 * name(class Foo{})
 * // => "Foo"
 *
 * name(function bar(){})
 * // => "bar"
 *
 * name(Symbol.for("abc"))
 * // => "abc"
 *
 * name("foo")
 * // => "foo"
 *
 * name(1)
 * // => null
 */
const name = (value) => {
    var _a;
    if (lodash_1.isString(value)) {
        return value;
    }
    if (lodash_1.isSymbol(value)) {
        return (_a = Symbol.keyFor(value)) !== null && _a !== void 0 ? _a : null;
    }
    if (lodash_1.isFunction(value)) {
        return value.name;
    }
    return null;
};
exports.name = name;
//# sourceMappingURL=name.js.map