"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toMapBy = void 0;
const lodash_1 = require("lodash");
/**
 * Creates a map from an objects entries.
 *
 * @since 13.0.0
 * @category Lang
 * @param object Object to use.
 * @param keyMapper Function mapping an object key to a map key.
 * @param valueMapper Function mapping an object value to a map value.
 * @returns Map created from the object.
 * @example
 * toMap({a: 1, b: 4, c: 5}, key => { return { key }; }, value => value * 2)
 * // => Map{{key: "a"}: 2, {key: "b"}: 8, {key: "a"}: 10}
 */
const toMapBy = (object, keyMapper, valueMapper) => new Map(lodash_1.toPairs(object).map(([key, val]) => [
    keyMapper(key, val),
    valueMapper(key, val),
]));
exports.toMapBy = toMapBy;
//# sourceMappingURL=toMapBy.js.map