"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.visit = void 0;
const lodash_1 = require("lodash");
/**
 * Helper method recursively executing the callback against all object properties.
 * Only object-like values will have the callback executed.
 * If the same reference is encountered after the first time, it will be skipped.
 *
 * @internal
 */
const visit = (root, callback) => {
    const visitStack = new WeakSet();
    const visitObject = (target) => {
        visitStack.add(target);
        lodash_1.forIn(target, (value) => {
            if (lodash_1.isObject(value) && !visitStack.has(value)) {
                visitObject(value);
            }
        });
        callback(target);
    };
    visitObject(root);
};
exports.visit = visit;
//# sourceMappingURL=visit.js.map